@@ -555,8 +555,8 @@ class DataTransform(forms.ModelForm):
         super(DataTransform, self).__init__(*args, **kwargs)
         if hasattr(self.instance, 'accessory') and self.instance.accessory is not None:
             dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
-                                                                 formset=self.__class__,
-                                                                 fk_name='parent', form=DataTransform
+                                                                 fk_name='parent', form=DataTransform,
+                                                                 extra=0
                                                                  )
             self.nested_data_transformer_form = dataTransformerInlineFormset(
                 instance=self.instance,
@@ -619,8 +619,7 @@ class DataTransformRoot(forms.ModelForm):
         super(DataTransformRoot, self).__init__(*args, **kwargs)
         if hasattr(self.instance, 'accessory') and self.instance.accessory is not None:
             dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
-                                                                 formset=self.__class__,
-                                                                 fk_name='parent', form=DataTransform
+                                                                 fk_name='parent', form=DataTransform, extra=0
                                                                  )
             self.nested_data_transformer_form = dataTransformerInlineFormset(
                 instance=self.instance,
